pyprofit
########

.. image:: https://travis-ci.org/ICRAR/pyprofit.svg?branch=master
    :target: https://travis-ci.org/ICRAR/pyprofit

.. image:: https://img.shields.io/pypi/v/pyprofit.svg
    :target: https://pypi.python.org/pypi/pyprofit

.. image:: https://img.shields.io/pypi/pyversions/pyprofit.svg
    :target: https://pypi.python.org/pypi/pyprofit

*pyprofit* is a python wrapper for `libprofit <https://www.github.com/ICRAR/libprofit>`_.

*pyprofit* is available in `PyPI <https://pypi.python.org/pypi/pyprofit>`_
and thus can be easily installed via::

 pip install pyprofit
